require common/phytec-localversion.inc
require recipes-bsp/u-boot/u-boot-processor-sdk.inc

# Update the u-boot localversion with the commit hash
# and the BSP release tag if it is present
UBOOT_LOCALVERSION = "-g${@phytec_git_revision('${S}').__str__()}"
UBOOT_LOCALVERSION_append = "-${@phytec_git_release_tag('${S}').__str__()}"

UBOOT_SUFFIX ?= "img"

require ${COREBASE}/meta/recipes-bsp/u-boot/u-boot.inc

FILESEXTRAPATHS_prepend := "${THISDIR}/u-boot:"

DESCRIPTION = "u-boot bootloader for PHYTEC devices, based on TI's u-boot-ti-staging"

LICENSE = "GPLv2+"
LIC_FILES_CHKSUM = "file://Licenses/README;md5=a2c678cfd4a4d97135585cad908541c6"

UBOOT_GIT_URI = "git://git@stash.phytec.com/scm/pub/uboot-phytec.git"
UBOOT_GIT_PROTOCOL = "https"
SRC_URI	= "${UBOOT_GIT_URI};protocol=${UBOOT_GIT_PROTOCOL};branch=${RELEASE_BRANCH}"

PV_append = "+git_${RELEASE_VER}"

# u-boot needs devtree compiler to parse dts files
DEPENDS += "dtc-native bc-native lzop-native"

PACKAGECONFIG[atf] = "ATF=${STAGING_DIR_HOST}/boot/bl31.bin,,arm-trusted-firmware"
PACKAGECONFIG[optee] = "TEE=${STAGING_DIR_HOST}/boot/bl32.bin,,optee-os"

# optee-os is not a direct dependency, do not enable optee by default
PACKAGECONFIG_append_k3 = " atf"

EXTRA_OEMAKE += "${PACKAGECONFIG_CONFARGS}"

PROVIDES += "u-boot"
PKG_${PN} = "u-boot"
PKG_${PN}-dev = "u-boot-dev"
PKG_${PN}-dbg = "u-boot-dbg"

S = "${WORKDIR}/git"

# Support for secure devices - detailed info is in doc/README.ti-secure
TI_SECURE_DEV_PKG ?= ""
export TI_SECURE_DEV_PKG

# SPL (Second Program Loader)
SPL_BINARY = "MLO"
SPL_BINARY_k3 = "tispl.bin"

# SPL (Second Program Loader) to be loaded over UART
SPL_UART_BINARY = "u-boot-spl.bin"
SPL_UART_BINARY_k3 = ""

SPL_UART_IMAGE ?= "${SPL_UART_BINARY}-${MACHINE}-${PV}-${PR}"
SPL_UART_SYMLINK ?= "${SPL_UART_BINARY}-${MACHINE}"


do_install_append () {
    if [ "x${SPL_UART_BINARY}" != "x" ]
    then
        for config in ${UBOOT_MACHINE}; do
            install ${B}/${config}/spl/${SPL_UART_BINARY} ${D}/boot/${SPL_UART_IMAGE}_${config}
            ln -sf ${SPL_UART_IMAGE}_${config} ${D}/boot/${SPL_UART_BINARY}_${config}
        done
    fi
}

do_deploy_append () {
    cd ${DEPLOYDIR}
    if [ "x${SPL_UART_BINARY}" != "x" ]
    then
        for config in ${UBOOT_MACHINE}; do
            install ${B}/${config}/spl/${SPL_UART_BINARY} ${DEPLOYDIR}/${SPL_UART_IMAGE}_${config}
            rm -f ${DEPLOYDIR}/${SPL_UART_BINARY}_${config} ${DEPLOYDIR}/${SPL_UART_SYMLINK}_${config}
            ln -sf ${SPL_UART_IMAGE}_${config} ${DEPLOYDIR}/${SPL_UART_BINARY}_${config}
            ln -sf ${SPL_UART_IMAGE}_${config} ${DEPLOYDIR}/${SPL_UART_BINARY}
            ln -sf ${SPL_UART_IMAGE}_${config} ${DEPLOYDIR}/${SPL_UART_SYMLINK}_${config}
            ln -sf ${SPL_UART_IMAGE}_${config} ${DEPLOYDIR}/${SPL_UART_SYMLINK}
        done
    fi
}
