SECTION = "kernel"
DESCRIPTION = "Linux kernel for PHYTEC AM572x devices, based on TI's processor-sdk_03.02.00.05"
LICENSE = "GPLv2"
LIC_FILES_CHKSUM = "file://COPYING;md5=d7810fab7487fb0aad327b76f1be7cd7"

inherit kernel

require recipes-kernel/linux/linux-dtb.inc
require common/phytec-localversion.inc

# Update kernel localversion string with commit hash
# and the BSP release tag if it is present
KERNEL_LOCALVERSION = "-g${@phytec_git_revision('${S}').__str__()}"
KERNEL_LOCALVERSION_append = "-${@phytec_git_release_tag('${S}').__str__()}"

# Look in the generic major.minor directory for files
FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}-4.4:"

# Pull in the devicetree files into the rootfs
RDEPENDS_kernel-base += "kernel-devicetree"

# Add a run-time dependency for the VPE VPDMA firmware to be installed
# on the target file system.
RDEPENDS_kernel-base_append_dra7xx = " vpdma-fw"

# Add run-time dependency for PRU Ethernet firmware to the rootfs
#RDEPENDS_kernel-base_append_am5726 = " prueth-fw"
#RDEPENDS_kernel-base_append_am5728 = " prueth-fw"

KERNEL_EXTRA_ARGS += "LOADADDR=${UBOOT_ENTRYPOINT}"

COMPATIBLE_MACHINE = "am5726|am5728"

S = "${WORKDIR}/git"

# RELEASE_% information is valid for the following BSP releases:
#     BSP-Yocto-TISDK-AM57xx-PD17.1.1
RELEASE_BRANCH = "v4.4.32-phy"
RELEASE_VER = "v4.4.32-phy2"

#Set to AUTOREV for development purposes
#SRCREV = "${AUTOREV}"
PV = "4.4.32+git_${RELEASE_VER}"

# Append to the MACHINE_KERNEL_PR so that a new SRCREV will cause a rebuild
MACHINE_KERNEL_PR_append = "a"
PR = "${MACHINE_KERNEL_PR}"

KERNEL_GIT_URI = "git://git@stash.phytec.com/scm/pub/linux-phytec-ti.git"
KERNEL_GIT_PROTOCOL = "https"

SRC_URI = "${KERNEL_GIT_URI};protocol=${KERNEL_GIT_PROTOCOL};branch=${RELEASE_BRANCH};tag=${RELEASE_VER} \
	file://defconfig"
